==> SAGx_1.24.0.zip: SAGx/doc/samroc-ex.R <==
###################################################
### chunk number 1: 
###################################################
#line 64 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpceDAcd/R.INSTALL1a205ad/SAGx/inst/doc/samroc-ex.Rnw"
library("SAGx")
library("multtest")
data(golub)
set.seed(849867)
samroc.res <- samrocN(data = golub, formula = ~as.factor(golub.cl))
show(samroc.res)


###################################################
### chunk number 2: dummyex3 eval=FALSE
###################################################
## #line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpceDAcd/R.INSTALL1a205ad/SAGx/inst/doc/samroc-ex.Rnw"
## plot(samroc.res)


###################################################
### chunk number 3: 
###################################################
#line 84 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpceDAcd/R.INSTALL1a205ad/SAGx/inst/doc/samroc-ex.Rnw"
par(bg = "cornsilk")
plot(samroc.res)


###################################################
### chunk number 4: 
###################################################
#line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpceDAcd/R.INSTALL1a205ad/SAGx/inst/doc/samroc-ex.Rnw"
par(bg = "cornsilk")
hist(samroc.res@pvalues, xlab = "p-value", main ="", col = 'orange', freq  = F)
print(abline(samroc.res@p0,0, col = 'red'))


###################################################
### chunk number 5: 
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpceDAcd/R.INSTALL1a205ad/SAGx/inst/doc/samroc-ex.Rnw"
par(bg = "cornsilk")
fdrs <- pava.fdr(ps = samroc.res@pvalues)
plot(samroc.res@pvalues, fdrs$pava.local.fdr, type = 'n', xlab = "p-value", ylab = "False Discovery Rate (FDR)")
lines(lowess(samroc.res@pvalues, fdrs$pava.local.fdr), col = 'red')
lines(lowess(samroc.res@pvalues, fdrs$pava.fdr), col = 'blue')
legend(0.1,0.9,pch=NULL,col=c("red","blue"),c("pava local FDR","pava FDR"),lty = 1)


###################################################
### chunk number 6: 
###################################################
#line 128 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpceDAcd/R.INSTALL1a205ad/SAGx/inst/doc/samroc-ex.Rnw"
library("hu6800.db")
kegg <- as.list(hu6800PATH2PROBE)
probeset <- golub.gnames[,3]
GSEA.mean.t(samroc = samroc.res, probeset = probeset, pway = kegg[1],
type = "original", two.side = FALSE)

==> SAGx_1.26.0.zip: SAGx/doc/samroc-ex.R <==
###################################################
### chunk number 1: 
###################################################
#line 64 "samroc-ex.Rnw"
library("SAGx")
library("multtest")
data(golub)
set.seed(849867)
samroc.res <- samrocN(data = golub, formula = ~as.factor(golub.cl))
show(samroc.res)


###################################################
### chunk number 2: dummyex3 eval=FALSE
###################################################
## #line 76 "samroc-ex.Rnw"
## plot(samroc.res)


###################################################
### chunk number 3: 
###################################################
#line 84 "samroc-ex.Rnw"
par(bg = "cornsilk")
plot(samroc.res)


###################################################
### chunk number 4: 
###################################################
#line 100 "samroc-ex.Rnw"
par(bg = "cornsilk")
hist(samroc.res@pvalues, xlab = "p-value", main ="", col = 'orange', freq  = F)
print(abline(samroc.res@p0,0, col = 'red'))


###################################################
### chunk number 5: 
###################################################
#line 111 "samroc-ex.Rnw"
par(bg = "cornsilk")
fdrs <- pava.fdr(ps = samroc.res@pvalues)
plot(samroc.res@pvalues, fdrs$pava.local.fdr, type = 'n', xlab = "p-value", ylab = "False Discovery Rate (FDR)")
lines(lowess(samroc.res@pvalues, fdrs$pava.local.fdr), col = 'red')
lines(lowess(samroc.res@pvalues, fdrs$pava.fdr), col = 'blue')
legend(0.1,0.9,pch=NULL,col=c("red","blue"),c("pava local FDR","pava FDR"),lty = 1)


###################################################
### chunk number 6: 
###################################################
#line 128 "samroc-ex.Rnw"
library("hu6800.db")
kegg <- as.list(hu6800PATH2PROBE)
probeset <- golub.gnames[,3]
GSEA.mean.t(samroc = samroc.res, probeset = probeset, pway = kegg[1],
type = "original", two.side = FALSE)
